package de.duehl.vocabulary.japanese.logic.ownlists;

/**
 * Diese Enum-Klasse stellt die Gruppe dar, zu der eine Liste gehören kann.
 *
 * Dies ist nicht zu verwechseln mit der Kategorie und Unterkategorie, in der die Listen im
 * Programm angeordnet sind, hierbei geht es um die Gruppen von Listen, welche ich zum Download
 * anbiete.
 *
 * Für diese Gruppen kann sich der Benutzer interessieren (oder sie abwählen) und wird dann nur
 * informiert, wenn es nur in den Bereichen, die ihn interessieren, neuere Listen auf dem Server
 * gibt.
 *
 * Auch wird diese Gruppenbezeichnung dazu verwendet, damit sich das Programm merken kann, zu
 * welcher Gruppe zuletzt welche Version an bereitgestellten eigenen Listen heruntergeladen wurde.
 *
 * Ich kann natürlich nicht wissen, ob der Benutzer die heruntergeladenen Gruppen auch importiert
 * hat, aber das ist dann auch eher das Problem des Benutzers.
 *
 * @version 1.01     2024-10-03
 * @author Christian Dühl
 */

public enum OwnListGroup {

    FROM_ZERO_1("Japanese From Zero - Buch 1"),
    FROM_ZERO_2("Japanese From Zero - Buch 2"),
    FROM_ZERO_3("Japanese From Zero - Buch 3"),

    SCHRITT_FUER_SCHRITT_1("Japanisch Schritt für Schritt Band 1"),

    VHS_A1_1("VHS Bielefeld Kurs A1.1 bei Hiroko Watanabe-Schmidt ab März 2024"),
    VHS_A1_2("VHS Bielefeld Kurs A1.2 bei Hiroko Watanabe-Schmidt ab September 2024"),

    MARUGOTO_A1("Marugoto A1 Rikai und Katsudou"),
    ;

    /** Die Beschreibung der Gruppe. */
    private final String description;

    /**
     * Konstruktor.
     *
     * @param description
     *            Die Beschreibung der Gruppe.
     */
    private OwnListGroup(String description) {
        this.description = description;
    }

    /** Getter für die Beschreibung der Gruppe. */
    public String getDescription() {
        return description;
    }

}
