package de.duehl.vocabulary.japanese.ui.dialog.table.kanji;

import java.awt.Color;
import java.awt.Component;

import javax.swing.JLabel;
import javax.swing.JTable;

import de.duehl.swing.ui.tables.DifferentBackgroundsTableRendererWithChangingSize;

/**
 * Diese Klasse ist für das Rendern (die optische Darstellung) der Tabellenzellen zuständig. Sie
 * wurde von DifferentBackgroundsTableRendererWithChangingSize abgeleitet, um nicht für jede Zelle
 * eine neue Klasse zu erzeugen.
 *
 * Man kann den Vordergrund Hintergrund der Darstellung abhängig vom Abfrageerfolg der letzten
 * Abfragen gestalten.
 *
 * @version 1.01     2024-10-02
 * @author Christian Dühl
 */

public class KanjiTableRenderer extends DifferentBackgroundsTableRendererWithChangingSize {

    private static final long serialVersionUID = 1L;

    /**
     * Der Konstruktor, hier werden unsere Maps erzeugt.
     *
     * @param foregroundColor
     *            Vordergrundfarbe
     * @param backgroundColor
     *            Hintergrundfarbe
     */
    public KanjiTableRenderer(Color foregroundColor, Color backgroundColor) {
        super(foregroundColor, backgroundColor);
        setUseDifferentBackgrounds(true);
    }

    /**
     * Liefert eine Komponente für die anzuzeigende Zelle zurück. Die Hauptarbeit lassen wir
     * super.getTableCellRendererComponent(...) machen und hängen nur ein wenig Code dahinter.
     *
     * @param table
     *            Die Tabelle
     * @param value
     *            Das anzuzeigende Objekt (im Normalfall ein String)
     * @param isSelected
     *            Zeigt an, ob das Objekt selektiert wurde.
     * @param hasFocus
     *            Zeigt an, ob der Focus auf dieser Zelle liegt.
     * @param row
     *            Zeile in der die Zelle liegt.
     * @param column
     *            Spalte in der die Zelle liegt.
     */
    @Override
    public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected,
            boolean hasFocus, int row, int column) {
        int perhapsSortedRow;
        perhapsSortedRow = row;

        return getTableCellRendererComponentInternal(table, value, isSelected, hasFocus,
                perhapsSortedRow, column);
    }

    private Component getTableCellRendererComponentInternal(JTable table, Object value,
            boolean isSelected, boolean hasFocus, int row, int column) {
        JLabel createdLabel = (JLabel) super.getTableCellRendererComponent(table, value, isSelected,
                hasFocus, row, column);

        Color foreground;
        Color background;

        if (isSelected && isUseSwitchedColorsForSelection()) {
            foreground = createdLabel.getBackground();
            background = createdLabel.getForeground();
        }
        else {
            foreground = createdLabel.getForeground();
            background = createdLabel.getBackground();
        }

        if (isSelected && isUseSwitchedColorsForSelection()) {
            createdLabel.setForeground(background);
            createdLabel.setBackground(foreground);
        }
        else {
            createdLabel.setForeground(foreground);
            createdLabel.setBackground(background);
        }

        return createdLabel;
    }

}
